<?php
class KT_Zoho_Api {
	private static $instance;

	public static function instance() {
		if ( ! isset( self::$instance ) && ! ( self::$instance instanceof KT_Acuity_Integration_Connection ) ) {
			self::$instance = new KT_Zoho_Api();
		}

		return self::$instance;
	}


	public function get_modules() {
		$response = $this->make_request( 'GET', '/crm/v2/settings/modules' );
		return $response;
		// echo '<pre>';
		// print_r($response); die;
	}

	public function get_module_fields( $module_id, $fields_type = "" ) {

		$response = $this->make_request( 'GET', '/crm/v2/settings/fields', array( 'module'=>$module_id ) );
		$module_fields = array();
		// echo '<pre>';
		// print_r($response['fields']);' die';
		if ( isset( $response['fields'] ) && is_array( $response['fields'] ) ) {
			foreach ( $response['fields'] as $field ) {

				if ( isset( $field['field_read_only'] ) && $field['field_read_only'] === false && ! in_array( $field['data_type'], array( 'fileupload' ) ) ) { //visible = true
					$name = $field['api_name'];
					$v = array( 'label'=>$field['field_label'], 'name'=>$field['api_name'], 'type'=>$field['data_type'] );
					if ( isset( $field['custom_field'] ) && $field['custom_field'] === true ) {
						$v['custom'] = 'yes';
					}
					if ( $v['type'] == 'lookup' ) {
						if ( ! empty( $field['lookup']['module'] ) ) {
							$v['module'] = $field['lookup']['module'];
						}
					}else  if ( $v['type'] == 'multiselectlookup' ) {
						if ( ! empty( $field['multiselectlookup']['connected_module'] ) ) {
							$v['module'] = $field['multiselectlookup']['connected_module'];
							$v['linking_module'] = $field['multiselectlookup']['linking_module'];
							$ar = $this->make_request( 'POST', '/crm/v2/settings/fields', array( 'module'=>$v['linking_module'] ) );
							if ( ! empty( $ar['fields'] ) && is_array( $ar['fields'] ) ) {
								foreach ( $ar['fields'] as $f ) {
									if ( $f['data_type'] == 'lookup' && $f['lookup']['module'] == $module ) {
										$v['module_field'] = $f['api_name'];
									}
								}
							}

						}
						if ( empty( $v['module_field'] ) ) { continue; }
					}

					//$v['req']=$required;
					if ( isset( $field['length'] ) ) {
						$v["maxlength"] = $field['length'];
					}
					if ( ! empty( $field['pick_list_values'] ) ) {
						$ops = $eg = array();
						foreach ( $field['pick_list_values'] as $op ) {
							$ops[] = array( 'value'=>$op['actual_value'], 'label'=>$op['display_value'] );
							$eg[] = $op['actual_value'] . '=' . $op['display_value'];
						}
						$v['options'] = $ops;
						$v['eg'] = implode( ', ', array_slice( $eg, 0, 10 ) );
					}
					$module_fields[$name] = $v;
				}
			}
			//$fields['tags'] = array( 'label'=>'Tags', 'name'=>'tags', 'type'=>'tags', 'maxlength'=>'0' );
			//if(in_array($module,array('Leads','Contacts'))){
			//$fields['vx_attachments'] = array( 'label'=>'Attachments - Related List', 'name'=>'vx_attachments', 'type'=>'files', 'maxlength'=>'0' );

			if ( $fields_type == "options" ) {
				$field_options = array();
				if ( is_array( $fields ) ) {
					foreach ( $fields as $k=>$f ) {
						if ( isset( $f['options'] ) && is_array( $f['options'] ) && count( $f['options'] ) > 0 ) {
							$field_options[$k] = $f;
						}
					}
				}

				return $field_options;
			}
			// echo '<pre>';
			// print_r($module_fields); die;
			return $module_fields;
		}
		// echo '<pre>';
		// print_r($module_fields); die;
		return $module_fields;

	}

	public function get_users(){
		$users = array();
		$response = $this->make_request( 'GET', '/crm/v2/users', array('type'=>'ActiveConfirmedUsers') );
		if ( isset( $response['users'] ) && is_array( $response['users'] ) ) {
			foreach ( $response['users'] as $user ) {
				$users[$user['id']] =$user['full_name'];
			}
		}
		return $users;
	}

	public function get_record( $module_api_name, $reord_id ) {
		$response = $this->make_request( 'GET', '/crm/v2/'.$module_api_name.'/'.$reord_id );
		return $response;
	}


	public function make_request(  $method = 'GET', $uri = '', $params = null  ) {
		$authsettings     = get_option( 'kt_zoho_auth', true );
		$access_token = KTZoho_Auth::get_access_token();

		$url     = $authsettings['api_domain'] . $uri;

		$headers =  array( 'content-type'=>'application/json', 'Authorization'=>'Bearer ' . $access_token );

		// switch based on METHOD
		/***********
			// GET is for getting reecords
			// POST is for updating existing records and requires an ID
			************/

		// make the request
		$req_args = array(
			'method'    => $method,
			'headers'   => $headers,
			'sslverify' => false  // set to true in live envrio
		);

		switch ( $method ) {
		case 'GET':

			if ( ! empty( $params ) ) {
				$querystring = urldecode( http_build_query( $params ) );
				// append a query string to the url
				$url         = $url . '?' . $querystring;
			}

			break;
		case 'PUT':
		case 'POST':
		case 'PATCH':
			if ( ! empty( $params ) ) {
				$req_args['body'] = json_encode( $params );
			}
			break;

		}
		//print_r($req_args); die;
		// make the remote request
		$result = wp_remote_request( $url, $req_args );

		// handle response
		if ( ! is_wp_error( $result ) ) {
			//no error
			$response = json_decode( wp_remote_retrieve_body( $result ), true );
			return $response;

		} else {
			// error
			return $result->get_error_message();
		}

	}

}

function KT_Zoho_Api() {
	return KT_Zoho_Api::instance();
}

KT_Zoho_Api();
