<?php
class KT_Zoho_Field_Mapping {

	private $kt_fields = array();
	private $kt_tags = array();
	/**
	 * Constructor.
	 */
	public function __construct() {
		$status = get_option( 'kt_zoho_license_status' );
		if ( is_admin() && $status == 'valid' ) {
			add_action( 'add_meta_boxes', array( $this, 'add_metabox'  )        );
			add_action( 'save_post',      array( $this, 'save_metabox' ), 10, 2 );
		}else {
			add_action( 'admin_notices', array( $this, 'show_license_notice' ) );
		}
	}

	function show_license_notice() {
		$screen = get_current_screen();

		if ( isset( $screen->post_type ) && $screen->post_type == 'kt-zoho' ) {
?>
			<div class="notice notice-error">
				<p><?php _e( 'Geben Sie einen gültigen Lizenzschlüssel ein', 'sample-text-domain' ); ?></p>
			</div>
		<?php
		}
	}


	/**
	 * Adds the meta box.
	 */
	public function add_metabox() {

		add_meta_box( 'kt-zoho-integration-metabox', __( 'Klick-Tipp - ZOHO-Integration', 'textdomain' ), array( $this, 'render_metabox' ), 'kt-zoho', 'advanced', 'default' );
	}

	/**
	 * Renders the meta box.
	 */
	public function render_metabox( $post ) {

		// Add nonce for security and authentication.
		wp_nonce_field( 'kt_zoho_integration_nonce_action', 'kt_zoho_integration_nonce' );
		$module_fields ='';
		$modules = KT_Zoho_Api()->get_modules();

		// var_dump($modules); die;
		$saved_module_api_name = get_post_meta( $post->ID, 'zoho_module_api_name', true );
		if( !empty ( $saved_module_api_name ) ){
			$module_fields = KT_Zoho_Api()->get_module_fields( $saved_module_api_name );
			//echo '<pre>';print_r($module_fields); die;
		}

		$zoho_feed_action = get_post_meta( $post->ID, 'zoho_feed_action', true );

		$kt_zoho_field_mapping = get_post_meta(  $post->ID, 'kt_zoho_field_mapping', true );
		$zoho_kt_field_mapping = get_post_meta(  $post->ID, 'zoho_kt_field_mapping', true );
		$optin_processes = $this->get_optin_processes();
		$optin_process = get_post_meta(  $post->ID, 'optin_process', true );
		$wftrigger = get_post_meta(  $post->ID, 'wftrigger', true );
		$send_empty_fields = get_post_meta(  $post->ID, 'send_empty_fields', true );
		$duplicate_leads = get_post_meta(  $post->ID, 'duplicate_leads', true );
		$tags = $this->get_kt_tags();
		$kt_tags = (array)get_post_meta(  $post->ID, 'kt_tags', true );
		?>
		<style>
			#kt-zoho-integration-metabox label{
				width: 200px;
				display: inline-block;
				font-size: 14px;
				float: left;
			/* margin-bottom: 26px; */
			}
			#kt-zoho-integration-metabox  .kt-zoho-options-row{
				margin-bottom: 40px;
			}
			#kt-zoho-integration-metabox p{
				margin-left: 205px;
			}
			#kt-zoho-integration-metabox span.select2-selection.select2-selection--single {
				outline: none;
			}
		</style>

		<div class="kt-zoho-options-row">
			<label>Action</label>
			<select class="zoho_feed_action" id="" name="zoho_feed_action">
				<option <?php echo selected( $zoho_feed_action, 'kt_to_zoho', false ) ?> value='kt_to_zoho'>KT => ZOHO</option>
				<option <?php echo selected( $zoho_feed_action, 'zoho_to_kt', false ) ?> value='zoho_to_kt'>ZOHO => KT</option>
			</select>
		</div>

		<div class="kt-zoho-options-row">
			<label>Select Module</label>
			<?php
				if ( is_array( $modules ) ) { ?>
					<select class="zoho_module_api_name" id="" name="zoho_module_api_name">
						<option value=''>Module auswählen</option>
						<?php foreach ( $modules['modules'] as $module ) {
								if( $module['creatable'] == '1'){
									echo '<option ' . selected( $saved_module_api_name, $module['api_name'], false ) . 'value="' . $module['api_name'] . '" >' . $module['module_name'] . '</option>';
								}
						} ?>
					</select>
				<?php
				} else {
					if ( is_string( $modules ) ) {
						echo $modules;
					}
				}
			?>
		</div>

		<div class="kt-zoho-options-row webhook-variable-names-cont">
			<label>Webhook Variable Names </label>
			<div class="webhook-variable-names">
				<strong>Parameter Name: </strong><br/>
				<strong>Custom Parameter: </strong>
			</div>

		</div>

		<div class="kt-zoho-options-row zoho_to_kt_field">
			<label>Double-Optin-Prozess</label>
			<?php
				if ( is_array( $optin_processes ) ) { ?>
				<select class="optin_process" id="" name="optin_process">
						<option value=''>Double-Optin-Prozess auswählen</option>
						<?php foreach ( $optin_processes as $key=>$dop_label ) {
						echo '<option ' . selected( $optin_process, $key, false ) . 'value="' . $key . '" >' . $dop_label . '</option>';
					} ?>
				</select>
				<?php
				} else {
					echo $optin_processes;
				}
			?>
		</div>
		<div class="kt-zoho-options-row zoho_to_kt_field">
			<label>Assign Tags</label>
			<select class="kt-select-multiple" multiple="multiple" name="kt_tags[]">
				<?php foreach ( $tags as $fieldkey=>$field ) {
					$sel = in_array( $fieldkey, $kt_tags )? 'selected="selected"':'' ;
					echo '<option ' . $sel . 'value="' . $fieldkey . '" >' . $field . '</option>';
				} ?>
			</select>
		</div>

		<div class="kt-zoho-options-row kt_to_zoho_field">
			<label>Workflow starten</label>
			<input <?php checked( $wftrigger, true, true) ?> type="checkbox" name="wftrigger"> Enable
		</div>

		<div class="kt-zoho-options-row ">
			<label>Sendy Empty Fields</label>
			<input <?php checked( $send_empty_fields, true, true) ?> type="checkbox" name="send_empty_fields"> Enable
		</div>
		<div class="kt-zoho-options-row ">
			<label>Leere Felder aktualisieren</label>
			<input <?php checked( $duplicate_leads, true, true) ?> type="checkbox" name="duplicate_leads"> Enable
		</div>

		<div class="map-fields-clear-cache-btn"> <a class="button kt_zoho_clear_field_cache" href="javascript:void(0)">Klick-Tipp & ZOHO Felder neu laden</a></div>
		<!-- <a class="button webhook-btn" href="javascript:void(0)">Webhook</a> -->
		<div class="kt-zoho-options-row kt_to_zoho_field">
			<h3> Feld-Zuordnungen</h3>
			<div class="map-fields-cont">
				<div class="map-fields-index"># </div>
				<div class="map-fields-header">Zoho Felder </div>
				<div class="map-fields-header"> Klick-Tipp Felder</div>

				<div style="clear:both"></div>
				<div class="map-fields-block kt-to-zoho-map-fields-block">
				<?php
					KT_Zoho_Helper()->get_kt_to_zoho_field_mapping_rows( $module_fields, $kt_zoho_field_mapping );
					?>

				</div>
			</div>
		</div>


		<div class="kt-zoho-options-row zoho_to_kt_field">
			<h3> Feld-Zuordnungen</h3>
			<div class="map-fields-cont">
				<div class="map-fields-index"># </div>
				<div class="map-fields-header">Klick-Tipp Felder </div>
				<div class="map-fields-header">Zoho Felder </div>

				<div style="clear:both"></div>
				<div class="map-fields-block zoho-to-kt-map-fields-block">
				<?php
					KT_Zoho_Helper()->get_zoho_to_kt_field_mapping_rows( $module_fields, $zoho_kt_field_mapping );
					?>

				</div>
			</div>
		</div>


		<div class="kt-zoho-options-row kt_to_zoho_field">
				<label>Klick Tipp Outbound Url</label>
				<span class="kt-outbound-link">
				<?php
					$copy_url = '';
					$copy_url = home_url( '?klicktipp-outbound=true&zoho-feed-id=' . $post->ID );
					echo $copy_url;
				?>
				</span>
				<span class="button" style="vertical-align: middle;"  id="copy-kt-outbound-link">In die Zwischenablage Kopieren</span>
				<script>
				(function($){
					$(function(){
						var outbound_url = "<?php  echo home_url( '?klicktipp-outbound=true&zoho-feed-id=' ); ?>";

						new ClipboardJS('#copy-kt-outbound-link', {
							text: function(trigger) {
								//console.log(trigger)
								return $('.kt-outbound-link').text();
							}
						});
					})
				})(jQuery)
				</script>
		</div>

	<?php

	}



	/**
	 * Handles saving the meta box.
	 *
	 * @param int     $post_id Post ID.
	 * @param WP_Post $post    Post object.
	 * @return null
	 */
	public function save_metabox( $post_id, $post ) {
		// Add nonce for security and authentication.
		$nonce_name   = isset( $_POST['kt_zoho_integration_nonce'] ) ? $_POST['kt_zoho_integration_nonce'] : '';
		$nonce_action = 'kt_zoho_integration_nonce_action';

		// Check if nonce is set.
		if ( ! isset( $nonce_name ) ) {
			return;
		}

		// Check if nonce is valid.
		if ( ! wp_verify_nonce( $nonce_name, $nonce_action ) ) {
			return;
		}

		// Check if user has permissions to save data.
		if ( ! current_user_can( 'edit_post', $post_id ) ) {
			return;
		}

		// Check if not an autosave.
		if ( wp_is_post_autosave( $post_id ) ) {
			return;
		}

		// Check if not a revision.
		if ( wp_is_post_revision( $post_id ) ) {
			return;
		}
		if( isset($_POST['wftrigger'])){
			update_post_meta( $post_id, 'wftrigger', true );
		}else{
			update_post_meta( $post_id, 'wftrigger', false );
		}

		if( isset($_POST['send_empty_fields'])){
			update_post_meta( $post_id, 'send_empty_fields', true );
		}else{
			update_post_meta( $post_id, 'send_empty_fields', false );
		}
		if( isset($_POST['duplicate_leads'])){
			update_post_meta( $post_id, 'duplicate_leads', true );
		}else{
			update_post_meta( $post_id, 'duplicate_leads', false );
		}

	//	update_post_meta( $post_id, 'owner', $_POST['owner'] );
		update_post_meta( $post_id, 'zoho_feed_action', $_POST['zoho_feed_action'] );
		update_post_meta( $post_id, 'zoho_module_api_name', $_POST['zoho_module_api_name'] );
		update_post_meta( $post_id, 'optin_process', $_POST['optin_process'] );

		update_post_meta( $post_id, 'kt_tags', $_POST['kt_tags'] );
		update_post_meta( $post_id, 'kt_zoho_field_mapping', $_POST['kt_zoho_field_mapping'] );
		update_post_meta( $post_id, 'zoho_kt_field_mapping', $_POST['zoho_kt_field_mapping'] );
	}


	public function get_kt_tags() {
		$kt_tags = get_transient( 'kt_tags' );
		if ( ! empty( $kt_tags ) ) {
			return $kt_tags;
		}else {
			$connection = kt_zoho_connect_api();
			$message = '';
			if ( ! isset( $connection['success'] ) ) {
				$tags =   array( $connection['error'] );
			} else {
				$connector = $connection['success'];
				$tags = $connector->tag_index();
				if ( ! $tags ) {
					$tags = array( $connector->get_last_error() );
				}
				$connector->logout();
			}
			set_transient( 'kt_tags', $tags, 60 * 60 * 60 );
			return $tags;
		}
	}

	public function get_optin_processes() {
		$optin_processes = get_transient( 'optin_processes' );
		if ( ! empty( $optin_processes ) ) {
			return $optin_processes;
		}else {
			$connection = kt_zoho_connect_api();
			$message = '';
			if ( ! isset( $connection['success'] ) ) {
				$optin_processes =   array( $connection['error'] );
			} else {
				$connector = $connection['success'];
				$optin_processes = $connector->subscription_process_index();
				if ( ! $optin_processes ) {
					$optin_processes = array( $connector->get_last_error() );
				}
				$connector->logout();
			}
			set_transient( 'optin_processes', $optin_processes, 60 * 60 * 60 );
			return $optin_processes;
		}
	}


}
new KT_Zoho_Field_Mapping();
