<?php

class KT_Zoho_Helper {
	private static $instance;
	private $_webmerge_instance = null;

	public static function instance() {
		if ( ! isset( self::$instance ) && ! ( self::$instance instanceof KT_Zoho_Helper ) ) {
			self::$instance = new KT_Zoho_Helper();
		}

		return self::$instance;
	}

	public function get_domain() {
		$settings = get_option( 'kt_zoho_settings' );
		return isset( $settings['client_domain'] ) ? $settings['client_domain']: 'https://www.zohoapis.eu/';
	}

	public function __construct() {
		add_action( 'wp_ajax_kt_zoho_get_mapping_fields', array(  $this, 'kt_zoho_get_mapping_fields' ) );
		add_action( 'wp_ajax_kt_zoho_revoke', array( 'KTZoho_Auth', 'revoke' ) );
		add_action( 'wp_ajax_kt_zoho_clear_field_cache',  array( $this, 'clear_cache' ) );
	}

	public function kt_zoho_get_mapping_fields() {
		$feed_action = $_POST['feed_action'];
		$module_api_name = $_POST['module_api_name'];
		$module_fields = KT_Zoho_Api()->get_module_fields( $module_api_name );

		if ( $feed_action == 'kt_to_zoho' ) {
			$this->get_kt_to_zoho_field_mapping_rows( $module_fields );
		} else {
			$this->get_zoho_to_kt_field_mapping_rows( $module_fields );
		}

		wp_die();
	}

	public function get_kt_to_zoho_field_mapping_rows( $module_fields, $kt_zoho_field_mapping = false ) {
		if ( empty( $module_fields ) ) {
			echo 'No Fields Found';
			return;
		}

		$kt_fields = $this->get_kt_fields();
		if ( is_array( $kt_fields ) ) {
			$default_fields = array(
				'subscriber_id' => 'Subscriber ID',
				'status' => 'Email Status',
				'bounce' => 'Bounce'
			);
			$kt_fields = $default_fields+$kt_fields;
		}
		$count = 1;
		foreach ( $module_fields as $module_field ) {
			$class = $count%2 == 0 ? "even":"odd";
			echo '<div class="field-mapping-row ' . $class . '">';
			echo '<span class="rowIndex">' . $count . '.</span>';
			echo '<span class="label">' . $module_field['label'] . '<br/>
				<span class="field-meta-info"><strong>Type</strong>= ' . $module_field['type'] . '</span>';
			if ( $module_field['type'] === 'picklist' || $module_field['type'] === 'multiselectpicklist' ) {
				$options = wp_list_pluck( $module_field['options'], 'value' );
				$options = implode( ', ', $options );
				echo '<span class="field-meta-info"><strong>Values</strong>= ' . $options . '</span>';
			}
			echo '</span>';
			echo '<select class="kt_field_select" name="kt_zoho_field_mapping[' . $module_field['name'] . ']">';
			echo '<option value="">Feld auswählen</option>';
			foreach ( $kt_fields as $id => $kt_field_label ) {
				$selected = '';
				if ( isset( $kt_zoho_field_mapping[$module_field['name']] ) ) {
					$selected = selected( $id, $kt_zoho_field_mapping[$module_field['name']] , false );
				}
				echo '<option ' . $selected . ' value="' . $id . '">' . $kt_field_label . '</option>';
			}
			echo '</select>';
			echo '</div>';
			$count++;
		}
	}

	public function get_zoho_to_kt_field_mapping_rows( $module_fields, $zoho_kt_field_mapping = false ) {
		if ( empty( $module_fields ) ) {
			echo 'No Fields Found';
			return;
		}
		// echo '<pre>';
		// print_r($module_fields); die;
		$module_fields = array( 'Owner'=>array('name'=>'Owner', 'label'=>'Owner' ))+$module_fields;
		$kt_fields = $this->get_kt_fields();
		//unset($kt_fields['email']);
		$count = 1;
		foreach ( $kt_fields as $kt_field_id => $kt_field_label ) {
			$class = $count%2 == 0 ? "even":"odd";
			echo '<div class="field-mapping-row ' . $class . '">';
			echo '<span class="rowIndex">' . $count . '.</span>';
			echo '<span class="label">' . $kt_field_label . '</span>';
			echo '<select class="kt_field_select" name="zoho_kt_field_mapping[' . $kt_field_id . ']">';
			echo '<option value="">Feld auswählen</option>';
			foreach ( $module_fields as $module_field ) {
				$selected = '';
				if ( isset( $zoho_kt_field_mapping[$kt_field_id] ) ) {
					$selected = selected(  $module_field['name'], $zoho_kt_field_mapping[$kt_field_id] , false );
				}
				echo '<option ' . $selected . ' value="' . $module_field['name'] . '">' . $module_field['label'] . '</option>';
			}
			echo '</select>';
			echo '</div>';
			$count++;
		}
	}

	public function get_kt_fields() {
		$kt_fields = get_transient( 'kt_fields' );

		if ( ! empty( $kt_fields ) ) {
			return $kt_fields;
		}else {

			$connection = kt_zoho_connect_api();
			$message = '';
			if ( ! isset( $connection['success'] ) ) {
				$fields =   array( $connection['error'] );
			} else {
				$connector = $connection['success'];

				$fields = $connector->field_index();

				if ( ! $fields ) {
					$fields = array( $connector->get_last_error() );
				}
				$extra_fields = array(
					'email'=>'Email',
					'smsnumber' =>'SMS-Mobilnummmer'
				);
				$fields = $extra_fields+$fields;
			}
			set_transient( 'kt_fields', $fields, 60 * 60 * 60 );
			return $fields;
		}
	}

	function clear_cache() {
		delete_transient( 'module_fields' );
		delete_transient( 'kt_fields' );
		delete_transient( 'kt_tags' );
		delete_transient( 'optin_processes' );
		wp_die();
	}


}

function KT_Zoho_Helper() {
	return KT_Zoho_Helper::instance();
}

KT_Zoho_Helper();
