<?php
class KT_Zoho_Settings {
	/**
	 * Autoload method
	 *
	 * @return void
	 */
	public function __construct() {
		add_action( 'admin_menu', array( &$this, 'register_sub_menu' ) );
		add_action( 'admin_init', array( $this, 'initialize_options' ) );

		add_action( 'admin_enqueue_scripts', array( $this, 'admin_scripts' ) );
	}
	function admin_scripts( $hook_suffix ) {
		$cpt = 'kt-zoho';

		if ( in_array( $hook_suffix, array( 'post.php', 'post-new.php' ) ) ) {
			$screen = get_current_screen();

			if ( is_object( $screen ) && $cpt == $screen->post_type ) {
				// Register, enqueue scripts and styles here
				wp_enqueue_style( 'wooselect', KT_ZOHO_PLUGIN_URL . '/css/selectWoo.min.css' );
				wp_enqueue_style( 'zoho-admin', KT_ZOHO_PLUGIN_URL . '/css/admin.css' );
				wp_enqueue_script( 'wooselect', KT_ZOHO_PLUGIN_URL . '/js/selectWoo.min.js' , array( 'jquery' ) );
				wp_enqueue_script( 'clipboard', KT_ZOHO_PLUGIN_URL . '/js/clipboard.min.js', array( 'jquery' ) );
				wp_enqueue_script( 'kt-zoho-admin-scripts', KT_ZOHO_PLUGIN_URL . '/js/admin-scripts.js' , array( 'jquery' ) );
			}
		}
	}

	/**
	 * Register submenu
	 *
	 * @return void
	 */
	public function register_sub_menu() {
		add_submenu_page( 'edit.php?post_type=kt-zoho', 'Einstellungen', 'Einstellungen', 'manage_options', 'kt-zoho-settings', array( &$this, 'settings_layout' ) );
	}

	/**
	 * Render submenu
	 *
	 * @return void
	 */
	public function settings_layout() { ?>
		<!-- Create a header in the default WordPress 'wrap' container -->
		<div class="wrap">

			<!-- Make a call to the WordPress function for rendering errors when settings are saved. -->
			<?php settings_errors(); ?>

			<!-- Create the form that will be used to render our options -->
			<form method="post" action="options.php">
				<?php settings_fields( 'kt_zoho_settings' ); ?>
				<?php do_settings_sections( 'kt_zoho_settings' ); ?>
				<?php submit_button(); ?>
			</form>

		</div><!-- /.wrap -->
<?php  }

	function initialize_options() {
		// If settings don't exist, create them.
		if ( false == get_option( 'kt_zoho_settings' ) ) {
			add_option( 'kt_zoho_settings' );
		} // end if

		add_settings_section(
			'kt_integration_settings_section',
			'Einstellungen',
			array( $this, 'section_callback' ),
			'kt_zoho_settings'
		);

		add_settings_field(
			'license_key',
			'Lizenzschlüssel',
			array( $this, 'settings_field' ),
			'kt_zoho_settings',
			'kt_integration_settings_section',
			array( 'field'=>'license_key' )
		);
		add_settings_field(
			'kt_username',
			'Klick-Tipp Benutzername',
			array( $this, 'settings_field' ),
			'kt_zoho_settings',
			'kt_integration_settings_section',
			array( 'field'=>'kt_username' )
		);

		add_settings_field(
			'kt_password',
			'Klick-Tipp Passwort',
			array( $this, 'settings_field' ),
			'kt_zoho_settings',
			'kt_integration_settings_section',
			array( 'field'=>'kt_password', 'type'=>'password' )
		);

		add_settings_section(
			'kt_zoho_settings_section',
			'Zoho Einstellungen',
			array( $this, 'section_callback' ),
			'kt_zoho_settings'
		);

		add_settings_field(
			'client_domain',
			'Client Domain',
			array( $this, 'client_domain' ),
			'kt_zoho_settings',
			'kt_zoho_settings_section',
			array( 'field'=>'client_domain' )
		);

		add_settings_field(
			'client_id',
			'Client ID',
			array( $this, 'settings_field' ),
			'kt_zoho_settings',
			'kt_zoho_settings_section',
			array( 'field'=>'client_id' )
		);

		add_settings_field(
			'client_secret',
			'Client Secret',
			array( $this, 'settings_field' ),
			'kt_zoho_settings',
			'kt_zoho_settings_section',
			array( 'field'=>'client_secret' )
		);
		add_settings_field(
			'client_code',
			'Client Code',
			array( $this, 'settings_field' ),
			'kt_zoho_settings',
			'kt_zoho_settings_section',
			array( 'field'=>'client_code' )
		);
		add_settings_field(
			'authorize_button',
			'',
			array( $this, 'authorize_btn' ),
			'kt_zoho_settings',
			'kt_zoho_settings_section'
		);

		add_settings_field(
			'enable_log',
			'Enable Logging',
			array( $this, 'log_field' ),
			'kt_zoho_settings',
			'kt_zoho_settings_section'
		);

		//register settings
		register_setting( 'kt_zoho_settings', 'kt_zoho_settings' );
	}

	function section_callback() {
		echo '';
	}

	function client_domain( $args ){
		$options = get_option( 'kt_zoho_settings' );
		$name = $args['field'];
		$value = ! empty( $options[$name] )? $options[$name] : '';

		echo '<select name="kt_zoho_settings[' . $name . ']" >';
		echo '<option '.selected('https://accounts.zoho.eu', $value, false ).' value="https://accounts.zoho.eu">zoho.eu</option>';
		echo '<option '.selected('https://accounts.zoho.com', $value, false ).' value="https://accounts.zoho.com">zoho.com</option>';
		echo '<option '.selected('https://accounts.zoho.com.cn', $value, false ).' value="https://accounts.zoho.com.cn">zoho.cn</option>';
		echo '<option '.selected('https://accounts.zoho.in', $value, false ).' value="https://accounts.zoho.in">zoho.in</option>';

	}

	function settings_field( $args ) {
		$options = get_option( 'kt_zoho_settings' );
		$name = $args['field'];
		$type = isset( $args['type'] ) ? $args['type'] : 'text';
		$value = ! empty( $options[$name] )? $options[$name] : '';

		// Render the output
		echo '<input type="' . $type . '" class="regular-text" id="' . $name . '" name="kt_zoho_settings[' . $name . ']" value="' . $value . '" />';
		if ( $name == 'license_key' ) {
			$status = get_option( 'kt_zoho_license_status' );
			$license_status = ( $status == 'valid' ) ?'Aktiv':'Inaktiv';
			echo '<input type="hidden" name="KT_ZOHO_license_input" value="1" >';
			echo '<span style="font-style:italic;font-size:12px">' . $license_status . '</span>';
		}
		$authsettings = get_option( 'kt_zoho_auth' );
		if ($name == 'client_code' && ! empty( $options['client_id'] ) && ! empty( $options['client_secret'] ) && ! empty(  $options['client_code'] ) && empty($authsettings['access_token']) )  {

			KTZoho_Auth::set_oauth2_token( $options['client_code'], 'auth_code' );
			//var_dump( get_option( 'kt_zoho_auth' ) );
		}

	}

	//function client_code

	public function authorize_btn() {
		$auth_error = get_option('kt_zoho_auth_error');
		$authsettings = get_option( 'kt_zoho_auth' );
		$settings = get_option( 'kt_zoho_settings' );

		$client_id = ! empty( $settings['client_id'] ) ? $settings['client_id'] : '';
		$client_secret = ! empty( $settings['client_secret'] ) ? $settings['client_secret'] : '';
		if ( ! empty( $client_id ) && empty( $authsettings['access_token'] ) ) {
			$auth_url = '';
			$btn_text = 'Not Authorized';
		} elseif ( ! empty( $client_secret ) && ! empty( $authsettings['access_token'] ) ) {
			$auth_url = KT_ZOHO_OAUTH2_REVOKE_URI . '/services/oauth2/revoke';
			$btn_text = 'Revoke Token';
			$class = 'kt_zoho_deauthorize';
		} else {
			$auth_url = '';
			$btn_text = 'Not Authorized';
		}
?>


		<?php
		if( ! empty( $auth_error ) ) {
			delete_option( 'kt_zoho_auth' );
			echo 'Error:: <span>'.$auth_error.' </span>';
		}else{ ?>
			<a  class="<?php echo esc_attr( $class ); ?>  button-secondary" href="<?php echo esc_url( $auth_url ); ?>"><?php echo esc_html( $btn_text ); ?></a>
			<span class="dashicons dashicons-yes" style="color:green"></span><span style="color:green">Authorized</span>
		<?php }
		?>

		<script type="text/javascript">
			( function ( $ ) {
			$( function () {

				$( '.kt_zoho_deauthorize' ).click( function ( e ) {
					e.preventDefault();

					var data = {
						action: 'kt_zoho_revoke',
					};
					$.post( ajaxurl, data, function ( response ) {
						location.reload();
					} );
				} )

			} )

		} )( jQuery )


	</script>

		<?php

	}

	function log_field() {
		$options = get_option( 'kt_zoho_settings' );
		$value = ! empty( $options['enable_log'] )? $options['enable_log'] : '';
		echo '<input ' . checked( '1', $value, false ) . ' type="checkbox" name="kt_zoho_settings[enable_log]" value="1"> Enable';
		echo'&nbsp;&nbsp;&nbsp;<a target="_blank" href="' . KT_ZOHO_PLUGIN_URL . '/logs/logs.php">View Log</a> ';
		echo '&nbsp;&nbsp;&nbsp;<a id="clear-kt-zoho-logfile" href="#">Clear Log</a> <span id="kt-zoho-clearing-cache" style="display:none">Clearing...</span>';
		echo '<p style="color:#a5a5a5">Check it to enable logging of webhook calls.</p>';
		?>
			<script type="text/javascript">
			( function ( $ ) {
			$( function () {

				$( 'body' ).on( 'click', '#clear-kt-zoho-logfile', function ( e ) {
						e.preventDefault();
						$( '#kt-zoho-clearing-cache' ).fadeIn();
						$.ajax( {
							url: ajaxurl,
							data: { action: 'clear_kt_zoho_log_file' },
							success: function ( response ) {
								$( '#kt-zoho-clearing-cache' ).fadeOut();
							}
						} )
					} )

			} )

		} )( jQuery )


	</script>
		<?php

	}

}

new KT_Zoho_Settings();
