<?php

class KT_Zoho_license_Updater {

	function __construct() {
		add_filter( 'update_option_kt_zoho_settings', array( $this, 'activate_license' ), 100 );
		add_action( 'admin_notices',  array( $this, 'admin_notices' ) );
		add_action( 'admin_init', array( $this, 'include_updater' ) );
		add_action( 'admin_init', array( $this, 'check_license' ) );

	}


	public static function include_updater() {
		$settings = get_option( 'kt_zoho_settings' );
		if ( ! empty( $settings ) ) {
			$license_key = isset( $settings['license_key'] )?$settings['license_key'] : '';
			if ( ! empty( $license_key ) ) {
				// setup the updater
				$edd_updater = new EDD_SL_Plugin_Updater( KT_ZOHO_STORE_URL, KT_ZOHO_PLUGIN_FILE, array(
						'version'  => KT_ZOHO_VERSION,
						'license'  => $license_key,
						'item_id' => KT_ZOHO_ITEM_ID,
						'author'  => 'Aman Saini'
					)
				);
			}
		}

	}


	function activate_license() {

		// listen for our activate button to be clicked
		//if ( isset( $_POST['KT_ZOHO_license_input'] ) ) {


		$settings = get_option( 'kt_zoho_settings' );
		if ( ! empty( $settings['license_key'] ) ) {
			//var_dump($settings['license_key']); die;
			// data to send in our API request
			$api_params = array(
				'edd_action' => 'activate_license',
				'license'    => $settings['license_key'],
				'item_id'  => urlencode( KT_ZOHO_ITEM_ID ),
				'url'        => home_url()
			);

			// Call the custom API.
			$response = wp_remote_post( KT_ZOHO_STORE_URL, array( 'timeout' => 15, 'sslverify' => false, 'body' => $api_params ) );

			// make sure the response came back okay
			if ( is_wp_error( $response ) || 200 !== wp_remote_retrieve_response_code( $response ) ) {

				if ( is_wp_error( $response ) ) {
					$message = $response->get_error_message();
				} else {
					$message = __( 'An error occurred, please try again.' );
				}

			} else {

				$license_data = json_decode( wp_remote_retrieve_body( $response ) );

				if ( false === $license_data->success ) {

					switch ( $license_data->error ) {

					case 'expired' :

						$message = sprintf(
							__( 'Your license key expired on %s.' ),
							date_i18n( get_option( 'date_format' ), strtotime( $license_data->expires, current_time( 'timestamp' ) ) )
						);
						break;

					case 'revoked' :

						$message = __( 'Your license key has been disabled.' );
						break;

					case 'missing' :

						$message = __( 'Invalid license Key.' );
						break;

					case 'invalid' :
					case 'site_inactive' :

						$message = __( 'Your license is not active for this URL.' );
						break;

					case 'item_name_mismatch' :

						$message = sprintf( __( 'This appears to be an invalid license key for KT Integrations.' ), WEPF_PRO_ITEM_NAME );
						break;

					case 'no_activations_left':

						$message = __( 'Your license key has reached its activation limit.' );
						break;

					default :

						$message = __( 'An error occurred, please try again.' );
						break;
					}

				}

			}

			// Check if anything passed on a message constituting a failure
			if ( ! empty( $message ) ) {
				$base_url = admin_url( 'edit.php?post_type=kt-zoho&page=kt-zoho-settings' );
				$redirect = add_query_arg( array( 'sl_activation' => 'false', 'message' => urlencode( $message ) ), $base_url );

				wp_redirect( $redirect );
				exit();
			}

			// $license_data->license will be either "valid" or "invalid"

			update_option( 'kt_zoho_license_status', $license_data->license );
			wp_redirect( admin_url( 'edit.php?post_type=kt-zoho&page=kt-zoho-settings' ) );
			exit();
		}

		//}
	}

	public  function check_license() {
		$license_status = get_transient( 'kt_zoho_license_status' );
		if ( ! $license_status ) {
			// check license

			$settings = get_option( 'kt_zoho_settings' );
			if ( ! empty( $settings['license_key'] ) ) {
				$api_params = array(
					'edd_action'=> 'check_license',
					'license'  => $settings['license_key'],
					'item_id' => urlencode( KT_ZOHO_ITEM_ID ),
					'url' => home_url()
				);
				// Call the custom API.
				$response = wp_remote_get( add_query_arg( $api_params, KT_ZOHO_STORE_URL ), array( 'timeout' => 15, 'sslverify' => false ) );

				// make sure the response came back okay
				if ( is_wp_error( $response ) )
					return false;

				// decode the license data
				$license_data = json_decode( wp_remote_retrieve_body( $response ) );

				// $license_data->license will be either "active" or "inactive"

				update_option( 'kt_zoho_license_status', $license_data->license );
				set_transient( 'kt_zoho_license_status', $license_data->license, 60 * 60 * 24 );
			}
		}

	}


	function admin_notices() {
		if ( isset( $_GET['sl_activation'] ) && ! empty( $_GET['message'] ) ) {

			switch ( $_GET['sl_activation'] ) {

			case 'false':
				$message = urldecode( $_GET['message'] );
?>
				<div class="error">
					<p><?php echo $message; ?></p>
				</div>
				<?php
				break;

			case 'true':
			default:
				// Developers can put a custom success message here for when activation is successful if they way.
				break;

			}
		}
	}
}

new KT_Zoho_license_Updater();
